wyzeapy.exceptions API documentation

# wyzeapy.exceptions

View Source

     1#  Copyright (c) 2021. Mulliken, LLC - All Rights Reserved
     2#  You may use, distribute and modify this code under the terms
     3#  of the attached license. You should have received a copy of
     4#  the license with this file. If not, please write to:
     5#  katie@mulliken.net to receive a copy
     6from typing import Dict, Any
     7
     8
     9class ActionNotSupported(Exception):
    10    def __init__(self, device_type: str):
    11        message = "The action specified is not supported by device type: {}".format(device_type)
    12
    13        super().__init__(message)
    14
    15
    16class ParameterError(Exception):
    17    pass
    18
    19
    20class AccessTokenError(Exception):
    21    pass
    22
    23
    24class LoginError(Exception):
    25    pass
    26
    27
    28class UnknownApiError(Exception):
    29    pass
    30
    31
    32class TwoFactorAuthenticationEnabled(Exception):
    33    pass

class ActionNotSupported(builtins.Exception): View Source

    10class ActionNotSupported(Exception):
    11    def __init__(self, device_type: str):
    12        message = "The action specified is not supported by device type: {}".format(device_type)
    13
    14        super().__init__(message)

Common base class for all non-exit exceptions.

ActionNotSupported(device_type: str) View Source

    11    def __init__(self, device_type: str):
    12        message = "The action specified is not supported by device type: {}".format(device_type)
    13
    14        super().__init__(message)

class ParameterError(builtins.Exception): View Source

    17class ParameterError(Exception):
    18    pass

Common base class for all non-exit exceptions.

class AccessTokenError(builtins.Exception): View Source

    21class AccessTokenError(Exception):
    22    pass

Common base class for all non-exit exceptions.

class LoginError(builtins.Exception): View Source

    25class LoginError(Exception):
    26    pass

Common base class for all non-exit exceptions.

class UnknownApiError(builtins.Exception): View Source

    29class UnknownApiError(Exception):
    30    pass

Common base class for all non-exit exceptions.

class TwoFactorAuthenticationEnabled(builtins.Exception): View Source

    33class TwoFactorAuthenticationEnabled(Exception):
    34    pass

Common base class for all non-exit exceptions.